:html_theme.sidebar_secondary.remove: 


*watex: machine learning research in water exploration*
==========================================================

.. grid:: 1 1 2 2

  .. grid-item::
    :columns: 12 12 7 7

    `WATex` is a :term:`Python` library focused on the :term:`groundwater` exploration. It 
    provides "smart" approaches to minimize losses during :term:`hydro-geophysical` engineering projects such as the automatic detection 
    of the best location for :term:`drilling` operations, predicting the :term:`permeability coefficient k`, recovering missing :term:`EM` tensors
    in :term:`dead-band` frequency, fitting :term:`EMAP` noised tensors to improve the :term:`SNR` ...

    **Features**: 
    |simpleicons git|  
    |Open Source? Yes!|  
    |License BSD| 
    |DOI|

  .. grid-item-card:: Useful resources — `Date`: |today|
    :columns: 12 12 5 5
    :class-title: sd-fs-6
    :class-body: sd-pl-3

    * :bdg-secondary:`New` :bdg-link-warning-line:`Issues & Ideas <https://github.com/WEgeophysics/watex/issues>` | :bdg-link-dark-line:`Source Repository <https://github.com/WEgeophysics/watex>` | :bdg-link-success-line:`Q&A Tags <https://stackoverflow.com/tags/watex>` 
    * :bdg-info:`Synopsis` :bdg-ref-primary-line:`Project story <history/project_story>` |:bdg-ref-info-line:`Mission & Goals <history/project_goals>` | :bdg-ref-secondary-line:`Applications <glr_examples/applications/index>` 

.. grid:: 

  .. grid-item:: 

      .. image:: _static/watex_thumb_image.svg
        :target: _static/watex_thumb_image.html


.. toctree::
  :maxdepth: 3
  :hidden: 

  Install <installation>
  API <api_references>
  User Guide <user_guide>
  Examples <glr_examples/index>
  Structure <structure>
  Development <development>
  Release notes <whatsnew/index>
  Citing <citing>
  About us <history/index>
  Glossary <glossary>
  

